@@ -11,19 +11,19 @@ rid = sys.argv[3].encode()
 
 ctx = zmq.Context()
 sock = ctx.socket(zmq.PUB)
-sock.connect('ipc://client-in')
+sock.connect("ipc://client-in")
 
 # await subscription
 time.sleep(0.01)
 
 resp = {}
-resp[b'from'] = b'sendresp'
-resp[b'id'] = rid
-resp[b'code'] = 200
-resp[b'reason'] = b'OK'
-resp[b'headers'] = [[b'Content-Type', b'text/plain']]
-resp[b'body'] = '{}\n'.format(body).encode()
+resp[b"from"] = b"sendresp"
+resp[b"id"] = rid
+resp[b"code"] = 200
+resp[b"reason"] = b"OK"
+resp[b"headers"] = [[b"Content-Type", b"text/plain"]]
+resp[b"body"] = "{}\n".format(body).encode()
 
-m = [addr + b' T' + tnetstring.dumps(resp)]
+m = [addr + b" T" + tnetstring.dumps(resp)]
 
 sock.send_multipart(m)
